<?php
namespace YpmPopup;
use \DateTime;

class Ajax
{
	public function __construct()
	{
		if(YPM_POPUP_PKG != YPM_POPUP_FREE) {
			require_once YPM_POPUP_CLASSES . 'form/YcfForm.php';
		}
		$this->init();
	}

	public function init()
	{
		add_action('wp_ajax_ypm-shape-form-element', array($this, 'YcfShapeElementsList'));
		add_action('wp_ajax_ypm-change-element-data', array($this, 'ycfChangeElementData'));
		add_action('wp_ajax_ypm-remove-element-from-list', array($this, 'ycfRemoveElementFromList'));
		add_action('wp_ajax_ypm-add-sub-option-option', array($this, 'ycfAddSubOption'));
		add_action('wp_ajax_ypm-delete-sub-option', array($this, 'ypmDeleteSubOption'));
		add_action('wp_ajax_ypm-sub-option-change', array($this, 'ypmSubOptionChange'));

		// review panel
		add_action('wp_ajax_ypm_dont_show_review_notice', array($this, 'dontShowReview'));
		add_action('wp_ajax_ypm_change_review_show_period', array($this, 'changeReviewPeriod'));

		add_action('wp_ajax_ypm_increment_popup_count', array($this, 'incrementPopupCount'));
		add_action('wp_ajax_nopriv_ypm_increment_popup_count', array($this, 'incrementPopupCount'));

		add_action('wp_ajax_ypm_reset_view_count', array($this, 'resetViewCount'));
	}


	public function changeReviewPeriod()
	{
		check_ajax_referer('ypmReviewNotice', 'ajaxNonce');
		$messageType = sanitize_text_field($_POST['messageType']);

		$timeDate = new DateTime('now');
		$timeDate->modify('+'.YPM_SHOW_REVIEW_PERIOD.' day');

		$timeNow = strtotime($timeDate->format('Y-m-d H:i:s'));
		update_option('YpmShowNextTime', $timeNow);
		$usageDays = get_option('YpmUsageDays');
		$usageDays += YPM_SHOW_REVIEW_PERIOD;
		update_option('YpmUsageDays', $usageDays);

		echo YPM_AJAX_SUCCESS;
		wp_die();
	}

	public function dontShowReview()
	{
		check_ajax_referer('ypmReviewNotice', 'ajaxNonce');
		update_option('YpmDontShowReviewNotice', 1);

		echo YPM_AJAX_SUCCESS;
		wp_die();
	}

	public function ycfRemoveElementFromList()
	{

		check_ajax_referer('ycfAjaxNonce', 'ajaxNonce');

		$elementData = $_POST['removeElementData'];
		$elementId = $elementData['id'];
		$draftElements = get_option('YcfPopupFormDraft');

		foreach ($draftElements as $key => $draftElement) {
			if($elementId == $draftElement['id']) {
				unset($draftElements[$key]);
			}
		}

		update_option('YcfPopupFormDraft', $draftElements);
		echo '1';
		die();
	}


	public function ycfChangeElementData()
	{
		check_ajax_referer('ycfAjaxNonce', 'ajaxNonce');

		$elementData = $_POST['editElementData'];
		$formId = $elementData['formCurrentId'];
		$changedElementId = $elementData['changedElementId'];
		$changedValue = $elementData['changedElementValue'];
		$changedKey = $elementData['changedElementKey'];

		if($formId == 0) {
			$formListData = get_option('YcfPopupFormDraft');
		}
		else {
			$formListData = YcfForm::getFormListById($formId);
		}

		if(is_array($formListData) && !empty($formListData)) {
			foreach($formListData as $key => $currentListFieldData) {
				if($currentListFieldData['id'] == $changedElementId) {
					if (!empty($_POST['isSettings'])) {
						$formListData[$key]['settings'][$changedKey] = $changedValue;
						break;
					}
					$formListData[$key][$changedKey] = $changedValue;
				}
			}
		}

		update_option('YcfPopupFormDraft', $formListData);
	}

	public function YcfShapeElementsList()
	{
		check_ajax_referer('ycfAjaxNonce', 'ajaxNonce');
		$formElement = $_POST['formElements'];

		require_once YPM_POPUP_CLASSES.'form/YcfContactForm.php';
		$formDataObj = new YcfContactForm();
		$currentElement = $formDataObj->getFormDefaultConfigByKey($formElement['type']);

		if($_POST['modification'] == 'add-element') {
			$this->addElementsToList($currentElement);
		}

		$args['oderId'] = $formElement['orderNumber'];

		$element = YcfForm::createAdminViewHtml($currentElement, $args);

		echo $element;
		die();
	}

	public function addElementsToList($formElement)
	{
		$formListData = get_option('YcfPopupFormDraft');

		$formSize = sizeof($formListData);

		array_splice($formListData, $formSize, 0, array($formElement));

		update_option('YcfPopupFormDraft', $formListData);
	}

	public function ycfAddSubOption()
	{
		check_ajax_referer('ycfAjaxNonce', 'ajaxNonce');
		$formId  = (int)$_POST['contactFormId'];
		$elementId = (int)$_POST['elementId'];
		$elementType = sanitize_text_field($_POST['elementType']);
		$elementOrderId = (int)$_POST['elementOrderId'];
		$newSubOptionName = sanitize_text_field($_POST['newSubOptionName']);
		$newSubOptionLabel = sanitize_text_field($_POST['newSubOptionLabel']);

		$elementOptions = $this->getElementOptionsById($formId, $elementId);

		$fieldOptions =  json_decode($elementOptions['fieldsOptions'], true);
		$fieldOptions =  $elementOptions['fieldsOptions'];
		$fieldsOrder =  json_decode($elementOptions['fieldsOrder'], true);
		$fieldsOrder =  $elementOptions['fieldsOrder'];

		$newSubOption = array(
			'label' => 	$newSubOptionLabel,
			'value' => $newSubOptionName,
			'orderId' => $elementOrderId,
			'options' => ''
		);
		$fieldOptions[] = $newSubOption;
		$fieldsOrder[] = $elementOrderId;
		//$fieldOptions = json_encode($fieldOptions);
		//$fieldsOrder = json_encode($fieldsOrder);
		$elementOptions['fieldsOptions'] = addslashes($fieldOptions);
		$elementOptions['fieldsOptions'] = $fieldOptions;
		$elementOptions['fieldsOrder'] = addslashes($fieldsOrder);
		$elementOptions['fieldsOrder'] = $fieldsOrder;

		//$elementOptions = json_encode($elementOptions);
		$this->changeElementOptions($formId, $elementId, $elementOptions);

		echo YcfForm::subOptionsGroupOptions($elementOrderId, $elementId, $newSubOptionName, $newSubOptionLabel);
		die();
	}

	public function getElementOptionsById($formId, $elementId)
	{
		$formListData = get_option("YcfPopupFormDraft");

		$optionsData = array();

		if(empty($formListData)) {
			return $optionsData;
		}

		foreach ($formListData as $key => $draftElement) {
			if($elementId == $draftElement['id']) {
				$optionData = $formListData[$key];
			}
		}

		if(empty($optionData['options'])) {
			return $optionsData;
		}

		$options = $optionData['options'];

		return $options;
	}

	public function changeElementOptions($formId, $elementId, $options)
	{
		$formListData = get_option('YcfPopupFormDraft');

		if(!$formListData) {
			return true;
		}

		foreach ($formListData as $key => $draftElement) {
			if($elementId == $draftElement['id']) {
				$formListData[$key]['options'] = $options;
			}
		}

		update_option('YcfPopupFormDraft', $formListData);
	}

	public function ypmDeleteSubOption()
	{
		check_ajax_referer('ycfAjaxNonce', 'ajaxNonce');

		$formId  = $_POST['contactFormId'];
		$elementId = $_POST['elementId'];
		$elementType = $_POST['elementType'];
		$elementOrderId = $_POST['elementOrderId'];
		$elementName = $_POST['elementName'];
		$elementValue = $_POST['elementValue'];
		$modificationType = $_POST['modificationType'];

		$elementOptions = $this->getElementOptionsById($formId, $elementId);

		$fieldOptions =  $elementOptions['fieldsOptions'];
		$fieldsOrder =  $elementOptions['fieldsOrder'];
		$modifiedOptions = $fieldOptions;

		foreach($fieldOptions as $key => $field) {
			if($field['orderId'] == $elementOrderId) {
				unset($modifiedOptions[$key]);

				if(($fieldsOrderKey = array_search($elementOrderId,$fieldsOrder)) !== false) {
					unset($fieldsOrder[$fieldsOrderKey]);
				}
			}
		}

		$elementOptions['fieldsOptions'] = $modifiedOptions;
		$elementOptions['fieldsOrder'] = $fieldsOrder;

		$this->changeElementOptions($formId, $elementId, $elementOptions);

		echo "";
		wp_die();
	}

	public function ypmSubOptionChange()
	{
		check_ajax_referer('ycfAjaxNonce', 'ajaxNonce');

		$formId  = $_POST['contactFormId'];
		$elementId = $_POST['elementId'];
		$elementType = $_POST['elementType'];
		$elementOrderId = $_POST['elementOrderId'];
		$elementName = $_POST['elementName'];
		$elementValue = $_POST['elementValue'];
		$modificationType = $_POST['modificationType'];

		$elementOptions = $this->getElementOptionsById($formId, $elementId);

		$fieldOptions =  $elementOptions['fieldsOptions'];

		if($modificationType == 'change') {
			foreach($fieldOptions as $key => $field) {
				if($field['orderId'] == $elementOrderId) {
					$fieldOptions[$key][$elementName] = $elementValue;
				}
			}

			$fieldOptions = $fieldOptions;
			$elementOptions['fieldsOptions'] = $fieldOptions;
		}
		$elementOptions = $elementOptions;
		$this->changeElementOptions($formId, $elementId, $elementOptions);
	}

	public function incrementPopupCount()
	{
		check_ajax_referer('ypmPMNonce', 'ajaxNonce');
		$popupId = sanitize_text_field($_POST['popupId']);
		$keyName = 'YpmPopupCount'.$popupId;

		$popupCounts = get_option($keyName);
		if (empty($popupCounts)) {
			$popupCounts = 0;
		}
		$popupCounts += 1;

		update_option($keyName, $popupCounts);

		echo 1;
		wp_die();
	}

	public function resetViewCount()
	{
		check_ajax_referer('ypmPmNonce', 'nonce');
		$postId = sanitize_text_field($_POST['postId']);
		update_option('YpmPopupCount'.$postId, 0);

		echo 1;
		wp_die();
	}
}

new Ajax();